@@ -42,6 +42,8 @@
 #' @template ssAuthor
 #' @template ssKeywords
 #'
+#' @template ADAMInitial
+#'
 #' @template ssGeneralRef
 #' @template ssIntermittentRef
 #' @template ssETSRef
@@ -83,20 +85,12 @@
 #' \code{lags=c(1,1,12)}. However, the function will also accept \code{lags=c(12)},
 #' assuming that the lags 1 were dropped.
 #' @param phi Value of damping parameter. If \code{NULL} then it is estimated.
-#' @param initial Can be either character or a vector of initial states.
-#' If it is character, then it can be \code{"optimal"}, meaning that all initial
-#' states are optimised, or \code{"backcasting"}, meaning that the initials of
-#' dynamic part of the model are produced using backcasting procedure (advised
-#' for data with high frequency). In the latter case, the parameters of the
-#' explanatory variables are optimised. This is recommended for ETSX
-#' model. Alternatively, you can set \code{initial="complete"} backcasting,
-#' which means that all states (including explanatory variables) are initialised
-#' via backcasting. You can also provide a vector with values for level and trend
-#' components.
-#' If character, then \code{initialSeason} will be estimated in the way defined
-#' by \code{initial}.
 #' @param initialSeason Vector of initial values for seasonal components. If
 #' \code{NULL}, they are estimated during optimisation.
+#' @param bounds What type of bounds to use in the model estimation. The first
+#' letter can be used instead of the whole word. \code{"usual"} implies restrictions on
+#' the smoothing parameter, guaranteeing that the exponential smoothing behaves
+#' as an averaging model. \code{"admissible"} guarantee that the model is stable.
 #' @param ...  Other non-documented parameters. For example \code{FI=TRUE} will
 #' make the function also produce Fisher Information matrix, which then can be
 #' used to calculated variances of smoothing parameters and initial states of
@@ -230,7 +224,8 @@
 #' @rdname es
 #' @export
 es <- function(y, model="ZZZ", lags=c(frequency(y)), persistence=NULL, phi=NULL,
-               initial=c("optimal","backcasting","complete"), initialSeason=NULL, ic=c("AICc","AIC","BIC","BICc"),
+               initial=c("backcasting","optimal","two-stage","complete"),initialSeason=NULL,
+               ic=c("AICc","AIC","BIC","BICc"),
                loss=c("likelihood","MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
                h=10, holdout=FALSE,
                # cumulative=FALSE,
