@@ -3,8 +3,6 @@
 #' (see \link[smooth]{gum}) and selects the best one based on the specified
 #' information criterion.
 #'
-#' @param ic The information criterion to use in the model selection.
-#'
 #' @seealso \code{\link[smooth]{gum}, \link[smooth]{es},
 #' \link[smooth]{ces}, \link[smooth]{sim.es}, \link[smooth]{ssarima}}
 #'
@@ -19,12 +17,11 @@
 #'
 #' @rdname gum
 #' @export
-auto.gum <- function(data, orders=3, lags=frequency(data), type=c("additive","multiplicative","select"),
-                     formula=NULL, regressors=c("use","select","adapt","integrate"),
-                     initial=c("backcasting","optimal","complete"), ic=c("AICc","AIC","BIC","BICc"),
+auto.gum <- function(y, orders=3, lags=frequency(y), type=c("additive","multiplicative","select"),
+                     initial=c("backcasting","optimal","two-stage","complete"), ic=c("AICc","AIC","BIC","BICc"),
                      loss=c("likelihood","MSE","MAE","HAM","MSEh","TMSE","GTMSE","MSCE"),
                      h=0, holdout=FALSE, bounds=c("admissible","none"), silent=TRUE,
-                     ...){
+                     xreg=NULL, regressors=c("use","select","adapt","integrate"), ...){
 # Function estimates several GUM models and selects the best one using the selected information criterion.
 #
 #    Copyright (C) 2017 - Inf  Ivan Svetunkov
@@ -38,37 +35,16 @@ auto.gum <- function(data, orders=3, lags=frequency(data), type=c("additive","mu
     # Record the parental environment. Needed for optimal initialisation
     env <- environment();
 
-# Add all the variables in ellipsis to current environment
-    list2env(ellipsis,environment());
-
     # If this is Mcomp data, then take the frequency from it
-    if(any(class(data)=="Mdata") && lags==frequency(data)){
-        lags <- frequency(data$x);
-        yInSample <- data$x;
+    if(any(class(y)=="Mdata") && lags==frequency(y)){
+        lags <- frequency(y$x);
+        yInSample <- y$x;
         # Measure the sample size based on what was provided as data
-        obsInSample <- length(data$x) - holdout*h;
+        obsInSample <- length(y$x) - holdout*h;
     }
     else{
         # Measure the sample size based on what was provided as data
-        if(!is.null(dim(data)) && length(dim(data))>1){
-            obsInSample <- nrow(data) - holdout*h;
-        }
-        else{
-            obsInSample <- length(data) - holdout*h;
-        }
-
-        if(!is.null(ncol(data)) && ncol(data)>1){
-            if(!is.null(formula)){
-                responseName <- all.vars(formula)[1];
-            }
-            else{
-                responseName <- colnames(xregData)[1];
-            }
-            y <- data[,responseName];
-        }
-        else{
-            y <- data;
-        }
+        obsInSample <- length(y) - holdout*h;
         yInSample <- y[1:obsInSample];
     }
 
@@ -145,12 +121,11 @@ auto.gum <- function(data, orders=3, lags=frequency(data), type=c("additive","mu
             cat(paste0(rep(" ",9+nchar(lags)),collapse=""));
         }
         for(i in 1:lags){
-            gumModel <- gum(data, orders=c(1), lags=c(i), type=type[t],
-                            formula=formula, regressors=regressors,
+            gumModel <- gum(y, orders=c(1), lags=c(i), type=type[t],
                             initial=initial, loss=loss,
                             h=h, holdout=holdout,
                             bounds=bounds, silent=TRUE, environment=env,
-                            ...);
+                            xreg=xreg, regressors=regressors, ...);
             ICs[i] <- IC(gumModel);
             if(!silent){
                 cat(paste0(rep("\b",nchar(paste0(i-1," out of ",lags))),collapse=""));
@@ -185,12 +160,11 @@ auto.gum <- function(data, orders=3, lags=frequency(data), type=c("additive","mu
                     ICs[i] <- 1E100;
                     next;
                 }
-                gumModel <- gum(data, orders=ordersTest, lags=lagsTest, type=type[t],
-                                formula=formula, regressors=regressors,
+                gumModel <- gum(y, orders=ordersTest, lags=lagsTest, type=type[t],
                                 initial=initial, loss=loss,
                                 h=h, holdout=holdout,
                                 bounds=bounds, silent=TRUE, environment=env,
-                                ...);
+                                xreg=xreg, regressors=regressors, ...);
                 ICs[i] <- IC(gumModel);
             }
             if(!any(which(ICs==min(ICs))==lagsBest)){
@@ -224,12 +198,11 @@ auto.gum <- function(data, orders=3, lags=frequency(data), type=c("additive","mu
                 ICs[i] <- NA;
                 next;
             }
-            gumModel <- gum(data, orders=ordersTest, lags=lagsBest, type=type[t],
-                            formula=formula, regressors=regressors,
+            gumModel <- gum(y, orders=ordersTest, lags=lagsBest, type=type[t],
                             initial=initial, loss=loss,
                             h=h, holdout=holdout,
                             bounds=bounds, silent=TRUE, environment=env,
-                            ...);
+                            xreg=xreg, regressors=regressors, ...);
             ICs[i] <- IC(gumModel);
         }
         ordersBest <- which(ICs==min(ICs,na.rm=TRUE),arr.ind=TRUE);
@@ -248,12 +221,11 @@ auto.gum <- function(data, orders=3, lags=frequency(data), type=c("additive","mu
         cat("Reestimating the model. ");
     }
 
-    bestModel <- gum(data, orders=ordersFinal[[t]], lags=lagsFinal[[t]], type=type[t],
-                     formula=formula, regressors=regressors,
+    bestModel <- gum(y, orders=ordersFinal[[t]], lags=lagsFinal[[t]], type=type[t],
                      initial=initial, loss=loss,
                      h=h, holdout=holdout,
                      bounds=bounds, silent=TRUE, environment=env,
-                     ...);
+                     xreg=xreg, regressors=regressors, ...);
 
     bestModel$timeElapsed <- Sys.time()-startTime;
 
