@@ -1,105 +1,9 @@
 utils::globalVariables(c("yForecastStart"));
 
-#' Simple Moving Average
-#'
-#' Function constructs state space simple moving average of predefined order
-#'
-#' The function constructs AR model in the Single Source of Error state space form
-#' based on the idea that:
-#'
-#' \eqn{y_{t} = \frac{1}{n} \sum_{j=1}^n y_{t-j}}
-#'
-#' which is AR(n) process, that can be modelled using:
-#'
-#' \eqn{y_{t} = w' v_{t-1} + \epsilon_{t}}
-#'
-#' \eqn{v_{t} = F v_{t-1} + g \epsilon_{t}}
-#'
-#' Where \eqn{v_{t}} is a state vector.
-#'
-#' For some more information about the model and its implementation, see the
-#' vignette: \code{vignette("sma","smooth")}
-#'
-#' @template ssBasicParam
 #' @template ssIntervals
-#' @template ssAuthor
-#' @template ssKeywords
-#'
-#' @template smoothRef
-#'
-#' @param order Order of simple moving average. If \code{NULL}, then it is
-#' selected automatically using information criteria.
-#' @param ...  Other non-documented parameters.  For example parameter
-#' \code{model} can accept a previously estimated SMA model and use its
-#' parameters.
-#' @return Object of class "smooth" is returned. It contains the list of the
-#' following values:
-#'
-#' \itemize{
-#' \item \code{model} - the name of the estimated model.
-#' \item \code{timeElapsed} - time elapsed for the construction of the model.
-#' \item \code{states} - the matrix of the fuzzy components of ssarima, where
-#' \code{rows} correspond to time and \code{cols} to states.
-#' \item \code{transition} - matrix F.
-#' \item \code{persistence} - the persistence vector. This is the place, where
-#' smoothing parameters live.
-#' \item \code{measurement} - measurement vector of the model.
-#' \item \code{order} - order of moving average.
-#' \item \code{initial} - Initial state vector values.
-#' \item \code{initialType} - Type of initial values used.
-#' \item \code{nParam} - table with the number of estimated / provided parameters.
-#' If a previous model was reused, then its initials are reused and the number of
-#' provided parameters will take this into account.
-#' \item \code{fitted} - the fitted values.
-#' \item \code{forecast} - the point forecast.
-#' \item \code{lower} - the lower bound of prediction interval. When
-#' \code{interval=FALSE} then NA is returned.
-#' \item \code{upper} - the higher bound of prediction interval. When
-#' \code{interval=FALSE} then NA is returned.
-#' \item \code{residuals} - the residuals of the estimated model.
-#' \item \code{errors} - The matrix of 1 to h steps ahead errors.
-#' \item \code{s2} - variance of the residuals (taking degrees of freedom into
-#' account).
-#' \item \code{interval} - type of interval asked by user.
-#' \item \code{level} - confidence level for interval.
-#' \item \code{cumulative} - whether the produced forecast was cumulative or not.
-#' \item \code{y} - the original data.
-#' \item \code{holdout} - the holdout part of the original data.
-#' \item \code{ICs} - values of information criteria of the model. Includes AIC,
-#' AICc, BIC and BICc.
-#' \item \code{logLik} - log-likelihood of the function.
-#' \item \code{lossValue} - Cost function value.
-#' \item \code{loss} - Type of loss function used in the estimation.
-#' \item \code{accuracy} - vector of accuracy measures for the
-#' holdout sample. Includes: MPE, MAPE, SMAPE, MASE, sMAE, RelMAE, sMSE and
-#' Bias coefficient (based on complex numbers). This is available only when
-#' \code{holdout=TRUE}.
-#' }
-#'
-#' @references \itemize{
-#' \item Svetunkov, I., & Petropoulos, F. (2017). Old dog, new tricks: a
-#' modelling view of simple moving averages. International Journal of
-#' Production Research, 7543(January), 1-14.
-#' \doi{10.1080/00207543.2017.1380326}
-#' }
-#'
-#' @seealso \code{\link[stats]{filter}, \link[smooth]{es}, \link[smooth]{ssarima}}
-#'
-#' @keywords SARIMA ARIMA
-#' @examples
-#'
-#' # SMA of specific order
-#' ourModel <- sma(rnorm(118,100,3),order=12,h=18,holdout=TRUE,interval="p")
-#'
-#' # SMA of arbitrary order
-#' ourModel <- sma(rnorm(118,100,3),h=18,holdout=TRUE,interval="sp")
-#'
-#' summary(ourModel)
-#' forecast(ourModel)
-#' plot(forecast(ourModel))
-#'
-#' @export sma
-sma <- function(y, order=NULL, ic=c("AICc","AIC","BIC","BICc"),
+#' @rdname sma
+#' @export
+sma_old <- function(y, order=NULL, ic=c("AICc","AIC","BIC","BICc"),
                 h=10, holdout=FALSE, cumulative=FALSE,
                 interval=c("none","parametric","likelihood","semiparametric","nonparametric"), level=0.95,
                 silent=c("all","graph","legend","output","none"),
